@@ -91,7 +91,8 @@ class CliTask:
             'check_architecture_supports_iso_firmware_setup': [],
             'check_appx_naming_conventions_valid': [],
             'check_syslinux_installed_if_isolinux_is_used': [],
-            'check_image_type_unique': []
+            'check_image_type_unique': [],
+            'check_include_references_unresolvable': []
         }
         self.checks_after_command_args = {
             'check_repositories_configured': [],
