@@ -1,8 +1,11 @@
+import logging
 import sys
 from mock import (
     call, patch, mock_open, Mock, MagicMock, ANY
 )
-from pytest import raises
+from pytest import (
+    raises, fixture
+)
 import kiwi
 
 from ..test_helper import argv_kiwi_tests
@@ -25,6 +28,10 @@ from kiwi.exceptions import (
 
 
 class TestDiskBuilder:
+    @fixture(autouse=True)
+    def inject_fixtures(self, caplog):
+        self._caplog = caplog
+
     @patch('os.path.exists')
     def setup(self, mock_exists):
         Defaults.set_platform_name('x86_64')
@@ -184,8 +191,9 @@ class TestDiskBuilder:
         kiwi.builder.disk.Fstab = Mock(
             return_value=self.fstab
         )
+        self.xml_state = XMLState(description.load())
         self.disk_builder = DiskBuilder(
-            XMLState(description.load()), 'target_dir', 'root_dir',
+            self.xml_state, 'target_dir', 'root_dir',
             custom_args={'signing_keys': ['key_file_a', 'key_file_b']}
         )
         self.disk_builder.root_filesystem_is_overlay = False
@@ -195,6 +203,13 @@ class TestDiskBuilder:
     def teardown(self):
         sys.argv = argv_kiwi_tests
 
+    def test_setup_warn_no_initrd_support(self):
+        self.boot_image_task.has_initrd_support = Mock(
+            return_value=False
+        )
+        with self._caplog.at_level(logging.WARNING):
+            DiskBuilder(self.xml_state, 'target_dir', 'root_dir')
+
     def test_setup_ix86(self):
         Defaults.set_platform_name('i686')
         description = XMLDescription(
@@ -530,7 +545,7 @@ class TestDiskBuilder:
     @patch('kiwi.builder.disk.Defaults.get_grub_boot_directory_name')
     @patch('os.path.exists')
     @patch('os.path.getsize')
-    @patch('kiwi.builder.disk.NamedTemporaryFile')
+    @patch('kiwi.builder.disk.Temporary.new_file')
     @patch('random.randrange')
     def test_create_disk_standard_root_is_overlay(
         self, mock_rand, mock_temp, mock_getsize, mock_exists,
@@ -544,7 +559,7 @@ class TestDiskBuilder:
         mock_squashfs.return_value = squashfs
         mock_getsize.return_value = 1048576
         tempfile = Mock()
-        tempfile.name = 'tempname'
+        tempfile.name = 'kiwi-tempname'
         mock_temp.return_value = tempfile
         mock_exists.return_value = True
         self.disk_builder.initrd_system = 'dracut'
@@ -565,16 +580,16 @@ class TestDiskBuilder:
             )
         ]
         assert squashfs.create_on_file.call_args_list == [
-            call(exclude=['var/cache/kiwi'], filename='tempname'),
+            call(exclude=['var/cache/kiwi'], filename='kiwi-tempname'),
             call(exclude=[
                 'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
                 '.buildenv', 'var/cache/kiwi',
                 'boot/*', 'boot/.*', 'boot/efi/*', 'boot/efi/.*'
-            ], filename='tempname')
+            ], filename='kiwi-tempname')
         ]
         self.disk.create_root_readonly_partition.assert_called_once_with(11)
         assert mock_command.call_args_list[2] == call(
-            ['dd', 'if=tempname', 'of=/dev/readonly-root-device']
+            ['dd', 'if=kiwi-tempname', 'of=/dev/readonly-root-device']
         )
         assert m_open.return_value.write.call_args_list == [
             call('kiwi_BootPart="1"\n'),
