@@ -82,7 +82,8 @@ class TestPackageManagerZypper:
             ['chroot', 'root-dir', 'zypper'] + self.chroot_zypper_args + [
                 'install', '--download', 'in-advance',
                 '--auto-agree-with-licenses'
-            ] + self.manager.custom_args + ['--', 'vim'], self.chroot_command_env
+            ] + self.manager.custom_args + ['--', 'vim'],
+            self.chroot_command_env
         )
 
     @patch('kiwi.command.Command.call')
@@ -114,7 +115,7 @@ class TestPackageManagerZypper:
         mock_run.side_effect = Exception
         self.manager.request_package('vim')
         with raises(KiwiRequestError):
-            self.manager.process_delete_requests()
+            self.manager.process_delete_requests(force=True)
         mock_run.assert_called_once_with(
             ['chroot', 'root-dir', 'rpm', '-q', 'vim']
         )
